@@ -1,8 +1,18 @@
 from django.db import models
-from django.contrib.auth import get_user_model
+from django.conf import settings
 from oauth2client.django_orm import CredentialsField
 
-User = get_user_model()
+
+class GoogleModel(models.Model):
+    def disconnect_twitter(self):
+        try:
+            tp = GoogleProfile.objects.get(user=self)
+            tp.delete()
+        except GoogleProfile.DoesNotExist:
+            pass
+
+    class Meta:
+        abstract = True
 
 
 class GoogleProfile(models.Model):
@@ -11,5 +21,5 @@ class GoogleProfile(models.Model):
         oauth_secret in relation to a user. Adapt this if you have a current
         setup, there's really nothing special going on here.
     """
-    user = models.OneToOneField(User)
+    user = models.OneToOneField(settings.AUTH_USER_MODEL)
     credential = CredentialsField()
